import setuptools

setuptools.setup(
    name='Pnav',
    version='0.1.8',
    author='Zander Navratil; Z_Nav',
    description='Package nav.',
    packages=['pnav'],
    long_description='run pnav.help.help() for more information or check out my github: https://github.com/ZNav'
)
